import { BrowserCapability, DriverInstance } from './types';
/**
 * log levels for the the logger
 */
export declare enum LogTypes {
    LOG = "log",
    ERROR = "error",
    WARN = "warn",
    INFO = "info"
}
/**
 * Abstract class to implement for wrapping an implementation of a Selenium web-driver
 */
export declare abstract class Driver<T extends DriverInstance = {
    quit: Function;
}, C extends BrowserCapability = BrowserCapability> {
    private name;
    protected capabilities: C;
    constructor(name: string, capabilities: C);
    private getDateForLog;
    protected logger(level: LogTypes, input: string | Error): void;
    abstract build(capabilities?: C, ...args: any[]): Promise<T>;
    abstract quit(): Promise<boolean | undefined>;
}
/**
 * Abstract class representing a plugin
 */
export declare abstract class PluginDriver<T extends Driver> {
    protected readonly moduleName: string;
    protected driver: T;
    constructor(moduleName: string);
    getName(): string;
    abstract createWdDriver<C extends BrowserCapability>(capabilities?: C, ...args: any[]): Promise<T>;
}
